@@ -114,7 +114,7 @@ def shutdown(send=signal.SIGSTOP, frame=None):
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
 
-def test():
+def test(): # pragma: no cover
     
     @exithandle
     def xhandle0(signum, frame=None):
