@@ -35,7 +35,7 @@ from clu.naming import nameof, dotpath_split, dotpath_join, qualified_name
 
 from clu.predicates import (anyattrs, attr,
                             attr_search, item_search,
-                            mro, none_function, tuplize)
+                            mro, typeof, none_function, tuplize)
 
 from clu.repr import stringify, hexid
 from clu.typespace import types
@@ -180,9 +180,9 @@ class Registry(abc.ABC, metaclass=MetaRegistry):
         super(Registry, cls).__init_subclass__(**kwargs)
         
         # We were called with a class for which the values
-        # of appname, appspace, and __name__ have been assigned:
+        # of appname, appspace, and __name__ have been assigned –
+        # let’s register this subclass if the names are good:
         if cls.appname and cls.appspace and nameof(cls):
-            # Register this subclass if the names are good:
             if cls.qualname not in Registry.monomers[cls.appname]:
                 Registry.monomers[cls.appname][cls.qualname] = cls
     
@@ -563,6 +563,11 @@ class MetaModule(MetaRegistry):
         return dotpath_join(cls.prefix,
                             cls.name)
     
+    @property
+    def monomers(cls):
+        # Block access to the registry’s underlying data:
+        return {}
+    
     @classmethod
     def __prepare__(metacls, name, bases, **kwargs):
         """ Prepare the class-module namespace with an injected
@@ -621,7 +626,8 @@ class MetaModule(MetaRegistry):
         return cls
 
 @export
-class ModuleAlias(collections.abc.Hashable,
+class ModuleAlias(collections.abc.Callable,
+                  collections.abc.Hashable,
                   clu.abstract.ReprWrapper,
                   metaclass=MetaTypeRepr):
     
@@ -637,13 +643,13 @@ class ModuleAlias(collections.abc.Hashable,
     
     def __init__(self, origin, specializer):
         """ Initialize a ModuleAlias, with an origin class and a specializer type """
-        if not issubclass(origin, ModuleBase):
+        if not subclasscheck(origin, ModuleBase):
             raise TypeError('Specialization requires a Module type')
         if specializer is not None:
-            if not issubclass(specializer, ModuleBase):
+            if not subclasscheck(specializer, ModuleBase):
                 raise TypeError('Specialization requires a Module type')
-        self.origin = origin 
-        self.specializer = specializer
+        self.origin = typeof(origin)
+        self.specializer = typeof(specializer)
     
     def __hash__(self):
         return hash(self.origin) \
@@ -653,8 +659,11 @@ class ModuleAlias(collections.abc.Hashable,
         return tuplize(self.origin,
                        self.specializer)
     
+    def __call__(self, bases=tuple(), *args, **kwargs):
+        return self.__mro_entries__(chain(bases, args))
+    
     def inner_repr(self):
-        return f"origin=“{self.origin!r}”, specializer=“{self.specializer!r}”"
+        return f"origin=‘{self.origin!r}’, specializer=’{self.specializer!r}’"
     
     def __eq__(self, other):
         if not isinstance(other, type(self)):
@@ -701,9 +710,6 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
     appspace = None
     __loader__ = None
     
-    # Block access to the registry’s underlying data:
-    monomers = clu.abstract.ValueDescriptor({})
-    
     @classmethod
     def __init_subclass__(cls, appname=None, appspace=None, **kwargs):
         """ Properly set the “appname” and “appspace” class attributes
@@ -756,7 +762,7 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
     
     @property
     def name(self):
-        return nameof(self)
+        return type(self).name
     
     @property
     def prefix(self):
@@ -764,8 +770,9 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
     
     @property
     def qualname(self):
-        return dotpath_join(self.prefix,
-                            self.name)
+        cls = type(self)
+        return dotpath_join(cls.prefix,
+                            cls.name)
     
     def __reduce__(self):
         return (Registry.for_qualname,
@@ -825,7 +832,7 @@ class PolymerType(dict):
                               appname=appname)
         return self[appname]
     
-    def add_module(self, appname, appspace, module):
+    def add_module(self, module, appname, appspace):
         """ Add a “clu.importing.ModuleBase” subtype to a given
             ‘PerApp’ record already existent in the PolymerType
             dictionary index.
@@ -929,9 +936,8 @@ def initialize_types(appname, appspace=consts.DEFAULT_APPSPACE):
             Module = initialize_module(appname,
                                        appspace,
                                        module=thismodule())
-            polymers.add_module(appname=appname,
-                               appspace=appspace,
-                                 module=Module)
+            polymers.add_module(Module, appname=appname,
+                                       appspace=appspace)
     
     if appname not in installed_appnames():
         sys.meta_path.append(Finder)
@@ -1291,8 +1297,6 @@ def test():
         assert o
         assert d
         assert O
-        
-        # from clu.app import DerivedModule as dd
     
     @inline
     def test_three():
@@ -1309,13 +1313,8 @@ def test():
         m = Module(consts.APPNAME)
         
         assert len(Registry.monomers) > 0
-        
-        try:
-            assert len(m.monomers) == 0
-        except AttributeError:
-            pass
-        else:
-            pass
+        assert len(Module.monomers) == 0
+        assert not hasattr(m, 'monomers')
         
         assert m.appname == consts.APPNAME
         assert m.appspace == consts.DEFAULT_APPSPACE
@@ -1325,6 +1324,9 @@ def test():
         print("mro(m):")
         pprint(mro(m))
         print()
+        
+    class FindMe(Module):
+        pass
     
     @inline
     def test_three_point_five():
@@ -1333,9 +1335,6 @@ def test():
         assert type(finder.loader) is Loader
         assert type(finder) in sys.meta_path
         
-        class FindMe(Module):
-            pass
-        
         spec0 = finder.find_spec('clu.app.FindMe', [])
         assert spec0.name == 'clu.app.FindMe'
         
@@ -1347,6 +1346,12 @@ def test():
         
         spec1 = finder.find_spec('clu.app.FindMe', [])
         assert spec1.name == 'clu.app.FindMe'
+        
+        # If “FindMe” is defined inline, this next assert fails –
+        # not the first time, but one of the 2..100 other times
+        # the test function runs:
+        registered = Registry.for_qualname('clu.app.FindMe')
+        assert registered == FindMe
     
     @inline
     def test_four():
@@ -1385,9 +1390,6 @@ def test():
         print()
         
         assert type(derived.exporter).__name__ == 'Exporter'
-        
-        # Registry.unregister(derived.appname,
-        #                     derived.qualname)
     
     @inline
     def test_five():
